@@ -1,5 +1,5 @@
 executionCode = """
-import sys, json, os, importlib
+import sys, json, os, importlib, traceback
 from bson import json_util
 
 try:
@@ -61,7 +61,8 @@ except Exception as ex:
   sys.stderr = temp_stderr
   if not stdfile is None:
     stdfile.close()
-  err = "Error " + str(ex)
+  errtrace = traceback.format_exc()
+  err = "Error " + str(errtrace)
   data = json.dumps({"error": err}, default=json_util.default)
   sys.stdout.write(data)
 
